<?
/*------------------------------------------------------------------------

# cls_iresizer.php - YO Pixel Controller

# ------------------------------------------------------------------------

# author    YOphp Site

# copyright Copyright (C) 2010 yophp.com. All Rights Reserved.

# @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL

# Websites: http://www.yophp.com

# Technical Support:  Forum - http://forum.yophp.com

-------------------------------------------------------------------------*/
class ImageResizer
{
	
	private $original_img = null;
	private $resized_img = null;
	private $w = 0;
	private $h = 0;
	private $exact = false; // true: generate an image with the exact size WxH, with lateral or horizontal image completion(with bgColor)
	private $bgR = 0;
	private $bgG = 0;
	private $bgB = 0;
	
		
	function loadImage($path) // filename/url
	{
		$imgparsers = array();
		$imgparsers[]='imagecreatefromjpeg';
		$imgparsers[]='imagecreatefromgif';
		$imgparsers[]='imagecreatefrompng';
		$imgparsers[]='imagecreatefromstring';
		$imgparsers[]='imagecreatefromwbmp';
		$imgparsers[]='imagecreatefromxbn';
		$imgparsers[]='imagecreatefromxpm';
		$img = false;
		foreach($imgparsers as $i=>$func)
			if(function_exists($func))
				if( $img = @$func($path) )
				{
					break;
				}
		if(!$img)
			return false;
		$this->original_img = $img;
				
		return true;		
	}//loadImage
	
	
	function setImage($img)
	{
		if($this->original_img!=null)
			@imagedestroy($this->original_img);
		$this->original_img = $img;
	}//setImage

	function checkColorCode($code)
	{
		if(is_numeric($code)&&0<=$code&&$code<256)
			return $code;
		else return 0;
	}//checkColorCode

	// if $exact is true the result image will be EXACTLY of the specified size, while
	//     still keeping original aspect ratio; empty areas may result horizontally or vertically,
	//     which will be filled with the color specified in RGB format by bgR, bgG and bgB  
	function setExactSizeResult($exact, $bgR=0, $bgG=0, $bgB=0)
	{
		if($exact)
			$this->exact = true;
		$this->bgR = $this->checkColorCode($bgR);
		$this->bgG = $this->checkColorCode($bgG);
		$this->bgB = $this->checkColorCode($bgB);
	}//setExactResult
	
	// w -- desired Width of the result
	// h -- desired Height of the result
	// mode -- 0 = 'resize to at most w x h'; neither width nor height of the result image will be greater than w and h respectively
	//      -- 1 = 'resize to at least w x h'; neither width nor height of the result will be smaller than w or h respectively 	
	function resize($w,$h,$mode=0)
	{
		if($this->original_img==null)
			return;
		if($this->resized_img!=null)
			@imagedestroy($this->resized_img);
		
		$ow = imagesx($this->original_img); //original width
		$oh = imagesy($this->original_img); //original height
		
		$img = imagecreatetruecolor($w,$h);
		imagecopyresampled($img,$this->original_img,0,0,0,0,$w,$h,$ow,$oh);
		
		$this->resized_img = $img;
		
	}//resize
	
	
	function getResult()
	{
		if($this->resized_img==null)
			return null;
		if( !$img = @imagecreatetruecolor( imagesx( $this->resized_img ), imagesy( $this->resized_img )  ) )
			return null;
		imagecopy( $img,$this->resized_img,0,0,0,0, imagesx( $this->resized_img ), imagesy($this->resized_img) );
		
		return $img;
	}//
	
	function freeResult()
	{
		if($this->resized_img!=null)
			@imagedestroy($this->resized_img);
	$this->resized_img=null;		
	}//freeResult
	
	function getOriginal()
	{
		return $this->original_img;
	}//getOriginal
	
	function __destruct()
	{
		if($this->original_img!=null)
			@imagedestroy($this->original_img);
		if($this->resized_img!=null)
			@imagedestroy($this->resized_img);
	}//destruct
	
}//ImageResizer

?>